package fr.emse.gitlab.saref.checkers;

import java.util.HashSet;
import java.util.Set;
import java.util.stream.Collectors;

import fr.emse.gitlab.saref.SAREF;
import fr.emse.gitlab.saref.SAREFPipeline;
import fr.emse.gitlab.saref.SAREFPipelineException;
import fr.emse.gitlab.saref.SAREFRepositoryErrorLogger;
import fr.emse.gitlab.saref.entities.SAREFRepository;
import fr.emse.gitlab.saref.entities.SAREFTerm;

public class TermsChecker extends SAREFRepositoryErrorLogger {
	
	private static final String TERMS="terms";

	public TermsChecker(SAREFPipeline pipeline, SAREFRepository repository) {
		super(pipeline, repository, pipeline.getLogger(SAREF.getMessage(TERMS)));
	}

	private static enum MESSAGE {
		not_defined
	}

	public void check() throws SAREFPipelineException {
		final Set<SAREFTerm> notDefined = new HashSet<>();
		
		for(SAREFTerm term: repository.getTerms().values()) {
			if(term.getIsDefinedBy().isEmpty() && !term.getIsUsedBy().isEmpty()) {
				notDefined.add(term);
			}
		}

		if (!notDefined.isEmpty()) {
			logWarning(getMessage(MESSAGE.not_defined,
					notDefined.stream().map(Object::toString).collect(Collectors.joining(", "))));
		}
	}
	
}
